/*********************************************************************
 *                    Flowcode Custom Component Code
 *
 * File: PIC_Custom.c
 *
 * (c) 2009 Matrix Multimedia Ltd.
 * http://www.matrixmultimedia.com
 *
 * Software License Agreement
 *
 * The software supplied herewith by Matrix Multimedia Ltd (the
 * Company) for its Flowcode graphical programming language is
 * intended and supplied to you, the Companys customer, for use
 * solely and exclusively on the Company's products. The software
 * is owned by the Company, and is protected under applicable
 * copyright laws. All rights are reserved. Any use in violation
 * of the foregoing restrictions may subject the user to criminal
 * sanctions under applicable laws, as well as to civil liability
 * for the breach of the terms and conditions of this licence.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * Changelog:
 *
 *  date  | by | description
 * -------+----+-----------------------------------------------------
 * 240407 | ST | Created
 *
 ********************************************************************/

/*********************************************************************

 Return & parameter types:
   void
   char
   short
   char*

 Pin directions:
   0 = OUTPUT
   2 = INPUT
   3 = BIDIRECTIONAL

**********************************************************************

[Settings]
CLSID={DA77448F-7831-4F3E-969E-6AE4EE551B6F}
IsAnalogue=0
MultipleAllowed=0
Description=Custom Flowcode Component

**********************************************************************

[Port]
DesiredPort=0
PortMandatory=0
SamePortAsID=0

[Pins]
Count=0

[PinPort]
# PORTA = 0
# PORTB = 1
# PORTC = 2
# PORTD = 3
# PORTE = 4

[PinDesiredBit]

[PinDirection]
# DIR_INPUT = 2
# DIR_OUTPUT = 0
# DIR_BIDIRECTIONAL = 3

[PinMustUsePort]
# boolean

[SamePortAsPinX]
# -1 = any pin
# otherwise, the pin number

[PinMustUsePin]
# boolean

[PinValue]
# boolean (0 = off, 1 = on)

**********************************************************************

[MacroNames]
Count=4
1=Increment_Val
2=InitSPISW
3=WriteSPISW
4=WriteCMD

[MacroReturns]
1=char
2=void
3=char
4=void

[MacroIsPrivate]
1=1
2=0
3=0
4=0

[MacroParameters_Increment_Val]
Count=1
1=nValue

[MacroParamTypes_Increment_Val]
1=char

[MacroParameters_InitSPISW]
Count=0


[MacroParamTypes_InitSPISW]


[MacroParameters_WriteSPISW]
Count=1
1=out

[MacroParamTypes_WriteSPISW]
1=char


[MacroParameters_WriteCMD]
Count=1
1=cmd

[MacroParamTypes_WriteCMD]
1=int

 ********************************************************************/

/********************************************************************
 * ADDITIONAL CODE
 ********************************************************************/

/*DefinesCode_Start*/

/**** Macro Substitutions ****
%a = User Define 1
%b = User Define 2
%c = User Define 3
%d = User Define 4
%e = User Define 5
%f = User Define 6
%g = User Define 7
%h = User Define 8
%i = User Define 9
%j = User Define 10
******************************/

//common defines
#define MX_Portb  	portb 	//	%a
#define MX_Trisb  	trisb	// 	%b
#define MX_CS  	portb.2	//	%c
#define MX_SCK  	portb.6	//	%d
#define MX_SDO  	portb.3	//	%e
#define MX_SDI  	portb.7	//	%f
#define MX_CUSTOM_7  %g
#define MX_CUSTOM_8  %h
#define MX_CUSTOM_9  %i
#define MX_CUSTOM_10 %j


//global variables
char CUSTOM_A;
char CUSTOM_B;


/*DefinesCode_End*/

/*InitialisationCode_Start*/
/*InitialisationCode_End*/

/*InterruptCode_Start*/
/*InterruptCode_End*/

/********************************************************************
 * FUNCTIONS
 ********************************************************************/

char Increment_Val(char nValue)
{
/*Macro_Increment_Val_Start*/
	return (nValue++);
/*Macro_Increment_Val_End*/
}


//public function implementations

void InitSPISW()
{
/*Macro_InitSPISW_Start*/
	trisb.2 = 0;
	trisb.6 = 0;
	trisb.3 = 0;
	trisb.7 = 1;
/*Macro_InitSPISW_End*/
}


char WriteSPISW(char out)
{
/*Macro_WriteSPISW_Start*/
	char in,i;
for (i=0;i<8;i++)
        {
        nop();
        nop();
        MX_SCK=0;                  //   
        nop();
        MX_SDO=out.7;              //  
        nop();
        out=out<<1;
        nop();                 // ,      
        nop();
        in=in<<1;
        MX_SCK=1;                  //   
        nop();
        in.0=MX_SDI;               //  
        }
return in;	 

/*Macro_WriteSPISW_End*/
}

void WriteCMD(int cmd)
{
/*Macro_WriteCMD_Start*/

     unsigned char Lo,Hi;
	 Lo = cmd; 					//  16     
                 Hi = (cmd >> 8);
      WriteSPISW(Hi);         	//    
      WriteSPISW(Lo);          	//    
 
/*Macro_WriteCMD_End*/
}